@@ -1,11 +1,12 @@
 #![allow(dead_code)]
 
 use std::io;
-use std::io::{Read, Write};
-use std::net::Shutdown;
+use std::io::{ErrorKind, Read, Write};
+use std::net::{Shutdown, ToSocketAddrs};
 use std::path::Path;
 
 use std::task::{Context, Poll};
+use std::time::Duration;
 use cogo::net::TcpStream;
 
 
@@ -15,11 +16,21 @@ pub struct Socket {
 }
 
 impl Socket {
+    pub fn connect_tcp_timeout(host: &str, port: u16, d: Duration) -> io::Result<Self> {
+        let mut addrs = (host, port).to_socket_addrs()?;
+        let next = addrs.next();
+        if next.is_none() {
+            return Err(io::Error::new(ErrorKind::NotFound, "addr not find"));
+        }
+        Ok(Self {
+            inner: TcpStream::connect_timeout(&next.unwrap(), d)?
+        })
+    }
 
     pub fn connect_tcp(host: &str, port: u16) -> io::Result<Self> {
-       Ok(Self{
-           inner: TcpStream::connect((host, port))?
-       })
+        Ok(Self {
+            inner: TcpStream::connect((host, port))?
+        })
     }
 
     pub fn shutdown(&mut self) -> io::Result<()> {
@@ -30,7 +41,7 @@ impl Socket {
 }
 
 impl std::io::Read for Socket {
-    fn read(&mut self, buf: &mut [u8]) -> io::Result<usize>{
+    fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
         self.inner.read(buf)
     }
 }
@@ -46,7 +57,7 @@ impl std::io::Write for Socket {
 }
 
 
-pub trait IsTLS{
+pub trait IsTLS {
     #[inline]
     fn is_tls(&self) -> bool;
 }
